=========================
SPADE Bokeh Server Plugin
=========================


.. image:: https://img.shields.io/pypi/v/spade_bokeh.svg
        :target: https://pypi.python.org/pypi/spade_bokeh

.. image:: https://img.shields.io/travis/javipalanca/spade_bokeh.svg
        :target: https://travis-ci.org/javipalanca/spade_bokeh

.. image:: https://readthedocs.org/projects/spade-bokeh/badge/?version=latest
        :target: https://spade-bokeh.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Bokeh server Plugin for SPADE agents that integrates with agents web service.
Allows to render dynamic bokeh plots inside the agent templates in a very easy way.


* Free software: MIT license
* Documentation: https://spade-bokeh.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
